#!/usr/local/bin/python
#
#    rutil.py
#    random number utility.
#    $Id: rutil.py,v 1.5 2020/04/06 05:15:09 daichi Exp $
#
from numpy.random import rand,randn,multinomial
from numpy import log, exp
from scipy.stats import gamma
import numpy as np
import time
import os

def srand ():
    if 'SEED' in os.environ:
        seed = int (os.getenv('SEED'))
    else:
        seed = int (time.time())
    np.random.seed (seed)

def dirichlet (alpha):
    xx = gamma.rvs (alpha)
    return xx / np.sum(xx)

def bernoulli (p):
    if rand() < p:
        return 1
    else:
        return 0

def multinom (p):
    occur = multinomial (1, p)
    return np.where (occur > 0)[0][0]

def pmultinom (p):
    return multinom (p / np.sum(p))

def lmultinom (lik):
    theta = exp (lik - logsumexp(lik))
    return multinom (theta)

def logsumexp (x):
    y = max (x)
    return y + log(sum(exp(x - y)))

def unif (low, high):
    return low + rand() * (high - low)
    
def main ():
    alpha = np.array ([1,2,3,4],dtype=float) / 100
    print (dirichlet (alpha))
    
if __name__ == "__main__":
    main ()
